@@ -53,11 +53,7 @@ static int
 is_regular_file (const char *filename)
 {
   struct stat st;
-
-  if (stat (filename, &st) == 0 && S_ISREG (st.st_mode))
-    return true;
-
-  return false;
+  return stat (filename, &st) == 0 && S_ISREG (st.st_mode);
 }
 
 /*
@@ -296,7 +292,7 @@ read_file (const char *filename)
               total_eols++;
               if (buf[i] == '\n')
                 this_eol_type = coding_eol_lf;
-              else if (i >= size || buf[i + 1] != '\n')
+              else if (i == size - 1 || buf[i + 1] != '\n')
                 this_eol_type = coding_eol_cr;
               else
                 {
@@ -657,13 +653,7 @@ copy_file (const char *source, const char *dest)
       return false;
     }
 
-  if (xasprintf (&tname, "%s_XXXXXXXXXX", dest) == -1)
-    {
-      minibuf_error ("Cannot allocate temporary file name `%s'",
-                     strerror (errno));
-      return false;
-    }
-
+  tname = xasprintf ("%s_XXXXXXXXXX", dest);
   ofd = mkstemp (tname);
   if (ofd == -1)
     {
