@@ -298,14 +298,14 @@ check_case (const char *s, size_t len)
 {
   size_t i;
 
-  if (!isupper ((int) *s))
-    return 0;
-
-  for (i = 1; i < len; i++)
-    if (!isupper ((int) s[i]))
-      return 1;
-
-  return 2;
+  for (i = 0; i < len && isupper ((int) s[i]); i++)
+    ;
+  if (i == len)
+    return 2;
+  else if (i == 1)
+    for (; i < len && !isupper ((int) s[i]); i++)
+      ;
+  return i == len;
 }
 
 /*
@@ -314,7 +314,7 @@ check_case (const char *s, size_t len)
  */
 void
 line_replace_text (Line * lp, size_t offset, size_t oldlen,
-                   char *newtext, int replace_case)
+                   const char *newtext, int replace_case)
 {
   int case_type = 0;
   size_t newlen = strlen (newtext);
@@ -491,7 +491,7 @@ bprintf (const char *fmt, ...)
   char *buf;
 
   va_start (ap, fmt);
-  xvasprintf (&buf, fmt, ap);
+  buf = xvasprintf (fmt, ap);
   va_end (ap);
   insert_nstring (buf, strlen (buf));
   free (buf);
