@@ -1,8 +1,8 @@
 (newline-and-indent)
-(next-line)
+(forward-line)
 (newline-and-indent)
-(next-line)
+(forward-line)
 (newline-and-indent)
 (newline-and-indent)
 (save-buffer)
-(save-buffers-kill-zile)
+(save-buffers-kill-emacs)
