@@ -174,7 +174,6 @@ main (int argc, char **argv)
 
   /* Set up Lisp environment now so it's available to files and
      expressions specified on the command-line. */
-  init_search ();
   init_lisp ();
   init_variables ();
   init_eval ();
@@ -233,8 +232,8 @@ main (int argc, char **argv)
 #define D(text)                                 \
           printf (text "\n");
 #define O(longname, shortname, arg, argstring, docstring)               \
-          xasprintf (&shortopt, ", -%c", shortname);                    \
-          xasprintf (&buf, "--%s%s %s", longname, shortname ? shortopt : "", argstring); \
+          shortopt = xasprintf (", -%c", shortname);                    \
+          buf = xasprintf ("--%s%s %s", longname, shortname ? shortopt : "", argstring); \
           printf ("%-24s%s\n", buf, docstring);                         \
           free (buf);                                                   \
           free (shortopt);
